fidetournament
==============

FIDE Tournament Report File (Krause format) parser and creator


Ref: http://ruby-doc.org/gems/docs/i/icu_tournament-1.6.8/ICU/Tournament/Krause.html

Format:
    Explanation: http://ratings.fide.com/download/fidexchg.txt
    Example file: http://ratings.fide.com/download/example1.txt
